@@ -190,7 +190,7 @@ class MagicSwitchbotDevice:
             self._device = btle.Peripheral(self._mac,
                                                   btle.ADDR_TYPE_PUBLIC,
                                                   self._interface)
-            _LOGGER.info("Connected to MagicSwitchbot at %s", self._mac)
+            _LOGGER.info("Connected to MagicSwitchbot at %s from hci%d", self._mac, self._interface)
             
             '''Initialize service and characteristics handles to the device'''
             self._service = self._device.getServiceByUUID(self.UUID_SERVICE)
@@ -394,7 +394,7 @@ class MagicSwitchbotDevice:
             '''First of all we check if there is a token to retrieve'''
             if command != self.CMD_GETTOKEN and self._token is None:
                 '''If the command is NOT GETTOKEN, we'll issue a GETOTKEN command before sending the actual command'''
-                go = self._auth(self._password)
+                go = self._auth()
             else:
                 go = True
             
